"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createEmptyTrashBinByModelTask = void 0;
var _tasks = require("@webiny/tasks");
var _common = require("../common");
var _types = require("../../types");
const createEmptyTrashBinByModelTask = () => {
  return (0, _tasks.createPrivateTaskDefinition)({
    id: _types.EntriesTask.EmptyTrashBinByModel,
    title: "Headless CMS - Empty trash bin by model",
    description: "Delete all entries found in the trash bin, by model.",
    maxIterations: 500,
    run: async params => {
      const {
        response,
        isAborted
      } = params;
      try {
        if (isAborted()) {
          return response.aborted();
        }
        const {
          EmptyTrashBinByModel
        } = await import( /* webpackChunkName: "EmptyTrashBinByModel" */"./useCases/EmptyTrashBinByModel");
        const emptyTrashBinByModel = new EmptyTrashBinByModel();
        return await emptyTrashBinByModel.execute(params);
      } catch (ex) {
        return response.error(ex.message ?? "Error while executing EmptyTrashBinByModel task");
      }
    },
    onDone: async ({
      context,
      task
    }) => {
      /**
       * We want to clean all child tasks and logs, which have no errors.
       */
      const childTasksCleanup = new _common.ChildTasksCleanup();
      try {
        await childTasksCleanup.execute({
          context,
          task
        });
      } catch (ex) {
        console.error("Error while cleaning `EmptyTrashBinByModel` child tasks.", ex);
      }
    }
  });
};
exports.createEmptyTrashBinByModelTask = createEmptyTrashBinByModelTask;

//# sourceMappingURL=emptyTrashBinByModelTask.js.map